/*
 * Florian Schäffer, www.blafusel.de
 * 27.03.2020
 * 
 * Connect to a HC-05 BT-Module and shows all devices MAC-addresses in area
 * 
 * https://www.itead.cc/wiki/Serial_Port_Bluetooth_Module_(Master/Slave)_:_HC-05
 * 
 */ 

#include <SoftwareSerial.h>       // https://www.arduino.cc/en/Reference/SoftwareSerial

const uint8_t Pin_RX = 10;
const uint8_t Pin_TX = 11;
const uint8_t Pin_KEY = 9;

SoftwareSerial BTSerial(Pin_RX, Pin_TX); // RX | TX

void setup() {}

void sendATcmd (char *cmd)
{
  BTSerial.write("AT+");
  BTSerial.write(cmd);
  BTSerial.write("\r\n");
  while (!BTSerial.available());
  while (BTSerial.available())
    Serial.write(BTSerial.read());
}

void loop() 
{
  pinMode(Pin_KEY, OUTPUT);       // this pin will pull the HC-05 pin 34 (key pin) HIGH to switch module to AT mode
  digitalWrite(Pin_KEY, HIGH);
  Serial.begin(115200);
  BTSerial.begin(38400);      // HC-05 default speed in AT command more

  Serial.println("Test about Bluetooth-Devices");
  Serial.println("Reset...");
  sendATcmd ("RESET");          // Reset
  delay (1000);
  Serial.println("Init...");
  sendATcmd ("ORGL");           // Restore default
  sendATcmd ("ROLE=1");         // puts the HC-05 in Master Mode
  sendATcmd ("CMODE=0");        // allows the HC-05 to connect to any device
  sendATcmd ("INQM=0,5,9");      // set inquiry to search for up to 5 devices for 9 seconds
  sendATcmd ("INIT");          // initiates the SPP profile. If SPP is already active you will get an error which you can ignore.
  Serial.println("Devices:");
  sendATcmd ("INQ");           // searches for other Bluetooth devices. returns 3 values, the first is the address and this is the value we need. The second value is the class of the device and the third value is the signal strength (RSSI).
  delay (15000);        // wait for response
  while (BTSerial.available())
    Serial.write(BTSerial.read());
  
  // delete comment and enter the MAC of one device to show the real name
  // sendATcmd ("RNAME?D,18,1");           // show name of given device ("+INQ:D:18:1,1F00,7FFF")
  sendATcmd ("RNAME?4,3E,98C20F");

  while(1);
}
